/**
 * Copyright (C) 2019-2021 Carl Kittelberger <icedream@icedream.pw>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import { availableLocales } from '../../util/localization';
import parseBool from '../../util/parseBool';
import withSession from '../../util/session';

export default withSession(async (req, res) => {
  if (!req.body) {
    res.status(400).json({
      success: false,
      error: 'bad request',
    });
    return;
  }

  if (req.body.volume !== null && req.body.volume !== undefined) {
    const volume = parseFloat(req.body.volume);
    req.session.set('volume', volume);
  }

  if (req.body.enableDark) {
    const enableDark = parseBool(req.body.enableDark);
    req.session.set('enable-dark', enableDark);
  }

  if (req.body.locale) {
    if (!availableLocales.includes(req.body.locale)) {
      res.status(400).json({
        success: false,
        error: 'wanted locale does not exist',
      });
    }
    req.session.set('locale', req.body.locale);
  }

  await req.session.save();

  res.json({
    success: true,
  });
});
